==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-70.js <==
dispMUA.arDispMUAAllocation["p"] =
{
  "posta elettronica internet di microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "plaasoft technologies php-mailer" : [ "plaasoft.png" ] ,
  "produced by pioneer investments" : [ "pioneerinvestments.png" , "http://www.pioneerinvestments.de/" ] ,
  "produced by microsoft exchange" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "produced by microsoft mimeole" : [ "ms_live.png" , "http://www.microsoft.com/" ] ,
  "paradise fast delivery agent" : [ "pfda.png" , "http://fda.omnisci.jp/FDA.html" ] ,
  "produced by confixx webmail" : [ "confixx.png" ] ,
  "protagona email services" : [ "protagona.png" ] ,
  "prospero mailing system" : [ "prospero.png" , "http://www.prospero.com/" ] ,
  "produced by swiftmailer" : [ "swiftmailer.png" , "http://www.swiftmailer.org/" ] ,
  "produced by msn mimeole" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "produced by nespresso" : [ "nespresso.png" , "http://www.nespresso.com/" ] ,
  "produced by mailworx" : [ "mailworx.png" , "http://www.mailworx.info/" ] ,
  "produced by myvideo" : [ "myvideo.png" , "" ] ,
  "powered by flowfact" : [ "flowfact.png" ] ,
  "poplist mailinglist" : [ "poplist.png" ] ,
  "python mail daemon" : [ "python.png" ] ,
  "produced by phpbb2" : [ "phpbb.png" ] ,
  "postmaster general" : [ "usps.png" , "http://www.postmastergeneral.com/" ] ,
  "pg-mailinglist pro" : [ "raynette.png" , "http://www.raynette.fr/script-pro/newsletter-mailing-list/" ] ,
  "penn state webmail" : [ "penn_state.png" ] ,
  "produced by eworx" : [ "eworx.png" , "http://www.eworx.at/" ] ,
  "pixum-html-mailer" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "projectplace.com" : [ "projectplace_com.png" , "http://www.projectplace.com/" ] ,
  "pixum newsletter" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "pinuts universal" : [ "pinuts.png" , "http://www.pinuts.de/Loesungen/universal_messenger/um_newsletter-edition/" ] ,
  "papageno gateway" : [ "papageno.png" , "http://www.com-em-tex.de/" ] ,
  "python syncmail" : [ "syncmail.png" ] ,
  "ptmail webmail" : [ "ptmail.png" ] ,
  "pineapple news" : [ "pineapplenews.png" ] ,
  "punbb mailer" : [ "punbb.png" ] ,
  "phoenix mail" : [ "phoenix_mail.png" ] ,
  "powermail -" : [ "powermail.png" ] ,
  "php/popmail" : [ "tinned-mail.png" ] ,
  "prosite.de" : [ "prosite_de.png" , "http://www.prosite.de/" ] ,
  "pop peeper" : [ "poppeeper.png" ] ,
  "pol-system" : [ "pol_system.png" ] ,
  "praktomat" : [ "praktomat.png" , "http://www.fim.uni-passau.de/de/fim/fakultaet/lehrstuehle/softwaresysteme/forschung/praktomat.html" ] ,
  "po4ta.com" : [ "po4ta_com.png" , "http://www.po4ta.com/" ] ,
  "pluriform" : [ "pluriform.png" ] ,
  "phpmailer" : [ "phpmailer.png" ] ,
  "pronews/" : [ "pronews.png" ] ,
  "pro dada" : [ "dada_mail.png" ] ,
  "prayer v" : [ "hermes_cambridge.png" ] ,
  "popmail/" : [ "popmail.png" ] ,
  "platypus" : [ "platypus.png" ] ,
  "phlymail" : [ "phlymail.png" ] ,
  "postpet" : [ "postpet.png" , "http://www.postpet.so-net.ne.jp/" ] ,
  "postaci" : [ "postaci.png" ] ,
  "porsche" : [ "porsche.png" , "http://www.porsche.com/" ] ,
  "pnphpbb" : [ "pnphpbb.png" , "http://www.pnphpbb.com/" ] ,
  "phorum5" : [ "phorum5.png" ] ,
  "pegasus" : [ "pegasus.png" ] ,
  "papyrus" : [ "papyrus_de.png" , "http://www.papyrus.de/" ] ,
  "postme" : [ "postme.png" ] ,
  "postie" : [ "postie.png" ] ,
  "pmw-tb" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "pmmail" : [ "pmmail.png" , "http://www.pmmail2000.com/" ] ,
  "paypal" : [ "paypal.png" ] ,
  "pochy" : [ "pochy.png" , "http://pochy.sourceforge.jp/" ] ,
  "pobox" : [ "pobox.png" ] ,
  "phpbb" : [ "phpbb.png" , "http://www.phpbb.com/" ] ,
  "poco" : [ "pocomail.png" ] ,
  "pine" : [ "pine.png" , "http://www.washington.edu/pine/" ] ,
  "perl" : [ "perl.png" ] ,
  "pepr" : [ "pear.png" ] ,
  "pear" : [ "pear.png" ] ,
  "pan/" : [ "pan.png" ] ,
  "pan " : [ "pan.png" ] ,
  "pse" : [ "interia_pl.png" , "http://www.interia.pl/" ] ,
  "php" : [ "php.png" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-70.js <==
dispMUA.arDispMUAAllocation["p"] =
{
  "posta elettronica internet di microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "plaasoft technologies php-mailer" : [ "plaasoft.png" ] ,
  "produced by pioneer investments" : [ "pioneerinvestments.png" , "http://www.pioneerinvestments.de/" ] ,
  "produced by microsoft exchange" : [ "ms_exchange.png" , "http://www.microsoft.com/" ] ,
  "produced by microsoft mimeole" : [ "ms_live.png" , "http://www.microsoft.com/" ] ,
  "paradise fast delivery agent" : [ "pfda.png" , "http://fda.omnisci.jp/FDA.html" ] ,
  "produced by confixx webmail" : [ "confixx.png" ] ,
  "protagona email services" : [ "protagona.png" ] ,
  "prospero mailing system" : [ "prospero.png" , "http://www.prospero.com/" ] ,
  "produced by swiftmailer" : [ "swiftmailer.png" , "http://www.swiftmailer.org/" ] ,
  "produced by msn mimeole" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "poczta.petroinform.net" : [ "petroinform_net.png" , "http://poczta.petroinform.net/" ] ,
  "produced by nespresso" : [ "nespresso.png" , "http://www.nespresso.com/" ] ,
  "poczta systemu ramzes" : [ "ramzes.png" , "http://www.ramzes.lubin.pl/" ] ,
  "produced by mailworx" : [ "mailworx.png" , "http://www.mailworx.info/" ] ,
  "produced by myvideo" : [ "myvideo.png" , "" ] ,
  "powered by flowfact" : [ "flowfact.png" ] ,
  "poplist mailinglist" : [ "poplist.png" ] ,
  "python mail daemon" : [ "python.png" ] ,
  "produced by phpbb2" : [ "phpbb.png" ] ,
  "postmaster general" : [ "usps.png" , "http://www.postmastergeneral.com/" ] ,
  "pg-mailinglist pro" : [ "raynette.png" , "http://www.raynette.fr/script-pro/newsletter-mailing-list/" ] ,
  "penn state webmail" : [ "penn_state.png" ] ,
  "push.infojobs.net" : [ "infojobs_net.png" , "http://www.infojobs.net/" ] ,
  "produced by eworx" : [ "eworx.png" , "http://www.eworx.at/" ] ,
  "pixum-html-mailer" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "projectplace.com" : [ "projectplace_com.png" , "http://www.projectplace.com/" ] ,
  "pixum newsletter" : [ "pixum.png" , "http://www.pixum.com/" ] ,
  "pinuts universal" : [ "pinuts.png" , "http://www.pinuts.de/Loesungen/universal_messenger/um_newsletter-edition/" ] ,
  "papageno gateway" : [ "papageno.png" , "http://www.com-em-tex.de/" ] ,
  "python syncmail" : [ "syncmail.png" ] ,
  "ptmail webmail" : [ "ptmail.png" ] ,
  "poczta gery.pl" : [ "gery_pl.png" , "http://www.gery.pl/" ] ,
  "pineapple news" : [ "pineapplenews.png" ] ,
  "phaser 6180mfp" : [ "xerox.png" , "http://www.xeroxdirect.com/" ] ,
  "punbb mailer" : [ "punbb.png" ] ,
  "phoenix mail" : [ "phoenix_mail.png" ] ,
  "powermail -" : [ "powermail.png" ] ,
  "poem mailer" : [ "poem-mailer.png" , "http://poem.crmstyle.com/" ] ,
  "php/popmail" : [ "tinned-mail.png" ] ,
  "prosite.de" : [ "prosite_de.png" , "http://www.prosite.de/" ] ,
  "pop peeper" : [ "poppeeper.png" ] ,
  "pol-system" : [ "pol_system.png" ] ,
  "praktomat" : [ "praktomat.png" , "http://www.fim.uni-passau.de/de/fim/fakultaet/lehrstuehle/softwaresysteme/forschung/praktomat.html" ] ,
  "po4ta.com" : [ "po4ta_com.png" , "http://www.po4ta.com/" ] ,
  "pluriform" : [ "pluriform.png" ] ,
  "phpmailer" : [ "phpmailer.png" ] ,
  "pronews/" : [ "pronews.png" ] ,
  "pro dada" : [ "dada_mail.png" ] ,
  "prayer v" : [ "hermes_cambridge.png" ] ,
  "popmail/" : [ "popmail.png" ] ,
  "platypus" : [ "platypus.png" ] ,
  "phlymail" : [ "phlymail.png" ] ,
  "postpet" : [ "postpet.png" , "http://www.postpet.so-net.ne.jp/" ] ,
  "postaci" : [ "postaci.png" ] ,
  "porsche" : [ "porsche.png" , "http://www.porsche.com/" ] ,
  "pnphpbb" : [ "pnphpbb.png" , "http://www.pnphpbb.com/" ] ,
  "phorum5" : [ "phorum5.png" ] ,
  "pegasus" : [ "pegasus.png" ] ,
  "papyrus" : [ "papyrus_de.png" , "http://www.papyrus.de/" ] ,
  "postme" : [ "postme.png" ] ,
  "postie" : [ "postie.png" ] ,
  "pmw-tb" : [ "thunderbird.png" , "http://www.mozilla-europe.org/en/products/thunderbird/" ] ,
  "pmmail" : [ "pmmail.png" , "http://www.pmmail2000.com/" ] ,
  "pluto/" : [ "pluto.png" , "http://home.clara.net/jsd/" ] ,
  "paypal" : [ "paypal.png" ] ,
  "pochy" : [ "pochy.png" , "http://pochy.sourceforge.jp/" ] ,
  "pobox" : [ "pobox.png" ] ,
  "phpbb" : [ "phpbb.png" , "http://www.phpbb.com/" ] ,
  "poco" : [ "pocomail.png" ] ,
  "pine" : [ "pine.png" , "http://www.washington.edu/pine/" ] ,
  "perl" : [ "perl.png" ] ,
  "pepr" : [ "pear.png" ] ,
  "pear" : [ "pear.png" ] ,
  "pan/" : [ "pan.png" ] ,
  "pan " : [ "pan.png" ] ,
  "pse" : [ "interia_pl.png" , "http://www.interia.pl/" ] ,
  "php" : [ "php.png" ] ,
}
